Index: kernel/genarch/include/drivers/pl050/pl050.h
===================================================================
--- kernel/genarch/include/drivers/pl050/pl050.h	(revision 48dcc699ceb1979a093dbc5c8b698fe7f16536ed)
+++ kernel/genarch/include/drivers/pl050/pl050.h	(revision be069144135afaab9e7c8cee79ffd3504762612c)
@@ -72,5 +72,5 @@
 #define PL050_STAT_RXFULL	(1 << 4)	/* 1: register Full */
 #define PL050_STAT_RXBUSY	(1 << 3)	/* 1: Busy, recieving Data */
-#define PL050_STAT_RXPARITY	(1 << 2)	/* odd parity of the last bit recieved */
+#define PL050_STAT_RXPARITY	(1 << 2)	/* odd parity of the last bit received */
 #define PL050_STAT_KMIC		(1 << 1)	/* status of KMICLKIN */
 #define PL050_STAT_KMID		1		/* status of KMIDATAIN */
Index: kernel/generic/include/sysinfo/abi.h
===================================================================
--- kernel/generic/include/sysinfo/abi.h	(revision 48dcc699ceb1979a093dbc5c8b698fe7f16536ed)
+++ kernel/generic/include/sysinfo/abi.h	(revision be069144135afaab9e7c8cee79ffd3504762612c)
@@ -90,8 +90,8 @@
 typedef struct {
 	uint64_t call_sent;           /**< IPC calls sent */
-	uint64_t call_recieved;       /**< IPC calls received */
+	uint64_t call_received;       /**< IPC calls received */
 	uint64_t answer_sent;         /**< IPC answers sent */
-	uint64_t answer_recieved;     /**< IPC answers received */
-	uint64_t irq_notif_recieved;  /**< IPC IRQ notifications */
+	uint64_t answer_received;     /**< IPC answers received */
+	uint64_t irq_notif_received;  /**< IPC IRQ notifications */
 	uint64_t forwarded;           /**< IPC messages forwarded */
 } stats_ipc_t;
Index: kernel/generic/src/proc/task.c
===================================================================
--- kernel/generic/src/proc/task.c	(revision 48dcc699ceb1979a093dbc5c8b698fe7f16536ed)
+++ kernel/generic/src/proc/task.c	(revision be069144135afaab9e7c8cee79ffd3504762612c)
@@ -197,8 +197,8 @@
 	
 	task->ipc_info.call_sent = 0;
-	task->ipc_info.call_recieved = 0;
+	task->ipc_info.call_received = 0;
 	task->ipc_info.answer_sent = 0;
-	task->ipc_info.answer_recieved = 0;
-	task->ipc_info.irq_notif_recieved = 0;
+	task->ipc_info.answer_received = 0;
+	task->ipc_info.irq_notif_received = 0;
 	task->ipc_info.forwarded = 0;
 	
@@ -478,5 +478,5 @@
 #ifdef __32_BITS__
 	if (*additional)
-		printf("%-8" PRIu64 " %9ld %7ld", task->taskid,
+		printf("%-8" PRIu64 " %9lu %7lu", task->taskid,
 		    atomic_get(&task->refcount), atomic_get(&task->active_calls));
 	else
@@ -489,5 +489,5 @@
 #ifdef __64_BITS__
 	if (*additional)
-		printf("%-8" PRIu64 " %9" PRIu64 "%c %9" PRIu64 "%c %9ld %7ld",
+		printf("%-8" PRIu64 " %9" PRIu64 "%c %9" PRIu64 "%c %9lu %7lu",
 		    task->taskid, ucycles, usuffix, kcycles, ksuffix,
 		    atomic_get(&task->refcount), atomic_get(&task->active_calls));
@@ -530,8 +530,8 @@
 #ifdef __64_BITS__
 	if (additional)
-		printf("[taskid] [ucycles ] [kcycles ] [threads] [calls]"
+		printf("[id    ] [ucycles ] [kcycles ] [threads] [calls]"
 		    " [callee\n");
 	else
-		printf("[taskid] [name        ] [ctx] [address         ]"
+		printf("[id    ] [name        ] [ctx] [address         ]"
 		    " [as              ]\n");
 #endif

Index: kernel/generic/src/ipc/ipc.c
===================================================================
--- kernel/generic/src/ipc/ipc.c	(revision 48dcc699ceb1979a093dbc5c8b698fe7f16536ed)
+++ kernel/generic/src/ipc/ipc.c	(revision be069144135afaab9e7c8cee79ffd3504762612c)
@@ -442,5 +442,5 @@
 	irq_spinlock_lock(&box->lock, true);
 	if (!list_empty(&box->irq_notifs)) {
 		/* Count recieved IRQ notification */
 		irq_cnt++;
 		
@@ -452,5 +452,5 @@
 		irq_spinlock_unlock(&box->irq_lock, false);
 	} else if (!list_empty(&box->answers)) {
 		/* Count recieved answer */
 		answer_cnt++;
 		
@@ -460,5 +460,5 @@
 		atomic_dec(&request->data.phone->active_calls);
 	} else if (!list_empty(&box->calls)) {
 		/* Count recieved call */
 		call_cnt++;
 		
@@ -477,7 +477,7 @@
 	irq_spinlock_pass(&box->lock, &TASK->lock);
 	
-	TASK->ipc_info.irq_notif_recieved += irq_cnt;
-	TASK->ipc_info.answer_recieved += answer_cnt;
-	TASK->ipc_info.call_recieved += call_cnt;
+	TASK->ipc_info.irq_notif_received += irq_cnt;
+	TASK->ipc_info.answer_received += answer_cnt;
+	TASK->ipc_info.call_received += call_cnt;
 	
 	irq_spinlock_unlock(&TASK->lock, true);
@@ -442,5 +442,5 @@
 	irq_spinlock_lock(&box->lock, true);
 	if (!list_empty(&box->irq_notifs)) {
-		/* Count recieved IRQ notification */
+		/* Count received IRQ notification */
 		irq_cnt++;
 		
@@ -452,5 +452,5 @@
 		irq_spinlock_unlock(&box->irq_lock, false);
 	} else if (!list_empty(&box->answers)) {
-		/* Count recieved answer */
+		/* Count received answer */
 		answer_cnt++;
 		
@@ -460,5 +460,5 @@
 		atomic_dec(&request->data.phone->active_calls);
 	} else if (!list_empty(&box->calls)) {
-		/* Count recieved call */
+		/* Count received call */
 		call_cnt++;
 		